server {
	listen      %ip%:%web_port%;
	server_name %domain_idn% %alias_idn%;
	root        %docroot%;
	index       index.php index.html index.htm;
	access_log  /var/log/nginx/domains/%domain%.log combined;
	access_log  /var/log/nginx/domains/%domain%.bytes bytes;
	error_log   /var/log/nginx/domains/%domain%.error.log error;
	#Если нужен редирект с http на https - раскомментируйте (уберите #) строку ниже.
	#rewrite ^(.*) https://$server_name$1 permanent;
	
	location / {
		try_files $uri $uri/ /index.php?$args;
 
		location ~* ^.+\.(jpeg|jpg|png|webp|gif|bmp|ico|svg|css|js)$ {
			expires     max;
		}
 
		# deny running scripts inside writable directories
		location ~* /(cache|static|upload)/.*\.(php|pl|py|jsp|asp|sh|cgi)$ {
			return 403;
		}
 
		location ~ [^/]\.php(/|$) {
			fastcgi_param SCRIPT_FILENAME $document_root$fastcgi_script_name;
			if (!-f $document_root$fastcgi_script_name) {
				return  404;
			}
 
			fastcgi_pass    %backend_lsnr%;
			fastcgi_index   index.php;
			fastcgi_param SCRIPT_FILENAME $document_root$fastcgi_script_name;
			include         /etc/nginx/fastcgi_params;
		}
 
 
 
	}
 
    error_page  403 /error/403.html;
    error_page  404 /error/404.html;
    error_page  500 502 503 504 /error/50x.html;
 
    location /error/ {
        alias   %home%/%user%/web/%domain%/document_errors/;
    }
 
    location /cache {
        location ~* \.(js|css|xml)$ {
            allow all;
        }
        deny all;
    }
 
    location /system {
        deny all;
    }
 
    location /templates {
        location ~ \.(js|css|scss|xml|png|gif|jpg|jpeg|ico|bmp|map|eot|svg|ttf|woff|woff2)$ {
            allow all;
        }
    }
 
    location /wysiwyg {
        autoindex off;
    }
 
    location /credits.txt {
        return 403;
    }
 
    location /readme.txt {
        return 403;
    }
 
    location ~ ^/license.(.*).txt$ {
        return 403;
    }
 
    location ~* "/\.(htaccess|htpasswd)$" {
        deny    all;
        return  404;
    }
 
    location ~ ^/sitemap(.*)\.xml$ {
        rewrite ^/sitemap(.*)\.xml$ /cache/static/sitemaps/sitemap$1.xml break;
    }
 
    location /vstats/ {
        alias   %home%/%user%/web/%domain%/stats/;
        include %home%/%user%/conf/web/%domain%.auth*;
    }
 
    include     /etc/nginx/conf.d/phpmyadmin.inc*;
    include     /etc/nginx/conf.d/phppgadmin.inc*;
    include     /etc/nginx/conf.d/webmail.inc*;
 
    include     %home%/%user%/conf/web/snginx.%domain%.conf*;
}
